fars_map_state: This function produces a map of accidents in a single state

Description Usage Arguments Value Examples

Description

This function produces a map of accidents in a single state

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

is an integer indicating which state's data will be filtered and then mapped. Parameter can be any integer 1-56.

year

is a single integer representing years reported on by the Fatality Analysis Reporting System. Parameter can years 2013-2015.

Value

This function returns a map showing the location of accidents in a single state from a single year based on data from the the Fatality Analysis Reporting System.

Examples

1
acc_years <- fars_map_state(10, 2015)

MPC24/fars2 documentation built on May 28, 2019, 1:45 p.m.