fars_read: Reads CSV file into R

Description Usage Arguments Value Examples

Description

This is a function that takes a filename as a parameter which is supposed to be a CSV file and reads that file into R and then converts it to a tibble dataframe.

Usage

1
fars_read(filename)

Arguments

filename

A file path of a CSV file to be converted

Value

This function returns a tibble dataframe from a CSV file. If the file path is wrong or the file does not exist then an error message will return.

Examples

1
2
3
acc_2015 <- fars_read("path/accident_2015.csv")
acc_2014 <- fars_read("path/accident_2014.csv")
acc_2013 <- fars_read("path/accident_2013.csv")

MPC24/fars2 documentation built on May 28, 2019, 1:45 p.m.