fars_read_years: This function return a list of dataframes

Description Usage Arguments Value Examples

Description

Applied accross multiple or single number of CSV files based on what is specified in the 'years' paramater; this function reads in CSV file(s) and converts them into a tibble dataframe and then selects only the 'MONTH' and 'year' columns.

Usage

1

Arguments

years

is a vector of integers or single integer representing years reported on by the Fatality Analysis Reporting System.

Value

This function returns a list of tibble dataframes containing the month and year varibles from the accident files from the Fatality Analysis Reporting System. The dataframes are compliled based on the years specified in a vector from the 'years' parameter. If only one year is provided that a simple tibble dataframe is returned.

Examples

1
acc_years <- fars_read_years(c(2013, 2014, 2015))

MPC24/fars2 documentation built on May 28, 2019, 1:45 p.m.