fars_summarize_years: This function summarizes a dataframe from CSV file

Description Usage Arguments Value Examples

Description

This function summarizes the number of accidents reported by the Fatality Analysis Reporting System by year and month.

Usage

1

Arguments

years

is a vector of integers or single integer representing years reported on by the Fatality Analysis Reporting System.

Value

This function returns a dataframe that summarizes the three dataframe objects from the list created by the 'fars_read_years' function. The dataframe contains four columns and twelve rows. The 'MONTH' column has the month number and the three year columns contain the number of fatalities in the corresponding month.

Examples

1
acc_years <- fars_summarize_years(c(2013, 2014, 2015))

MPC24/fars2 documentation built on May 28, 2019, 1:45 p.m.