make_filename: Creates filename for CSV file

Description Usage Arguments Value Examples

Description

This is a function that takes a year parameter and creates a filename for Fatality Analysis Reporting System data.

Usage

1

Arguments

year

is an integer that is a year reported by the Fatality Analysis Reporting System

Value

This function returns a tibble filepath for a CSV file containing data for the Fatality Analysis Reporting System

Examples

1
2
3

MPC24/fars2 documentation built on May 28, 2019, 1:45 p.m.