Description Usage Arguments Value Examples
This function produces a map of accidents in a single state
1 | fars_map_state(state.num, year)
|
state.num |
is an integer indicating which state's data will be filtered and then mapped. Parameter can be any integer 1-56. |
year |
is a single integer representing years reported on by the Fatality Analysis Reporting System. Parameter can years 2013-2015. |
This function returns a map showing the location of accidents in a single state from a single year based on data from the the Fatality Analysis Reporting System.
1 | acc_years <- fars_map_state(10, 2015)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.