Description Usage Arguments Value Examples
This is a function that takes a filename as a parameter which is supposed to be a CSV file and reads that file into R and then converts it to a tibble dataframe.
1 | fars_read(filename)
|
filename |
A file path of a CSV file to be converted |
This function returns a tibble dataframe from a CSV file. If the file path is wrong or the file does not exist then an error message will return.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.