Description Usage Arguments Value Examples
Applied accross multiple or single number of CSV files based on what is specified in the 'years' paramater; this function reads in CSV file(s) and converts them into a tibble dataframe and then selects only the 'MONTH' and 'year' columns.
1 | fars_read_years(years)
|
years |
is a vector of integers or single integer representing years reported on by the Fatality Analysis Reporting System. |
This function returns a list of tibble dataframes containing the month and year varibles from the accident files from the Fatality Analysis Reporting System. The dataframes are compliled based on the years specified in a vector from the 'years' parameter. If only one year is provided that a simple tibble dataframe is returned.
1 | acc_years <- fars_read_years(c(2013, 2014, 2015))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.