Description Usage Arguments Value Examples
This function summarizes the number of accidents reported by the Fatality Analysis Reporting System by year and month.
1 | fars_summarize_years(years)
|
years |
is a vector of integers or single integer representing years reported on by the Fatality Analysis Reporting System. |
This function returns a dataframe that summarizes the three dataframe objects from the list created by the 'fars_read_years' function. The dataframe contains four columns and twelve rows. The 'MONTH' column has the month number and the three year columns contain the number of fatalities in the corresponding month.
1 | acc_years <- fars_summarize_years(c(2013, 2014, 2015))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.