Description Usage Arguments Value Examples
This is a function that takes a year parameter and creates a filename for Fatality Analysis Reporting System data.
1 | make_filename(year)
|
year |
is an integer that is a year reported by the Fatality Analysis Reporting System |
This function returns a tibble filepath for a CSV file containing data for the Fatality Analysis Reporting System
1 2 3 | make_filename(2013)
make_filename(2014)
make_filename(2015)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.